<?php
/**
 * Theme functions and definitions
 *
 * @package shark_news_entertainment
 */ 


if ( ! function_exists( 'shark_news_entertainment_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function shark_news_entertainment_enqueue_styles() {
		wp_enqueue_style( 'shark-news-style-parent', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'shark-news-entertainment-style', get_stylesheet_directory_uri() . '/style.css', array( 'shark-news-style-parent' ), '1.0.0' );

		// Add custom fonts, used in the main stylesheet.
		wp_enqueue_style( 'shark-news-entertainment-fonts', shark_news_entertainment_fonts_url(), array(), null );
	}
endif;
add_action( 'wp_enqueue_scripts', 'shark_news_entertainment_enqueue_styles', 99 );

/**
 * Enqueue editor styles for Gutenberg
 */
function shark_news_entertainment_block_editor_styles() {
	// Add custom fonts.
	wp_enqueue_style( 'shark-news-entertainment-fonts', shark_news_entertainment_fonts_url(), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'shark_news_entertainment_block_editor_styles' );

if ( ! function_exists( 'shark_news_entertainment_fonts_url' ) ) :
/**
 * Register Google fonts
 *
 * @return string Google fonts URL for the theme.
 */
function shark_news_entertainment_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	/* translators: If there are characters in your language that are not supported by Oswald, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Oswald font: on or off', 'shark-news-entertainment' ) ) {
		$fonts[] = 'Oswald:300,400,500,600,700';
	}

	$query_args = array(
		'family' => urlencode( implode( '|', $fonts ) ),
		'subset' => urlencode( $subsets ),
	);

	if ( $fonts ) {
		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}
endif;

// Add class to body.
add_filter( 'body_class', 'shark_news_entertainment_add_body_class' );
function shark_news_entertainment_add_body_class( $classes ) {
    return array_merge( $classes, array( 'dark-mode', 'header-font-2' ) );
}

add_filter( 'shark_news_featured_widget_design', 'shark_news_entertainment_add_featured_widget_design' );
function shark_news_entertainment_add_featured_widget_design() {
    return 'layout-2';
}

add_filter( 'shark_news_slider_widget_design', 'shark_news_entertainment_add_slider_widget_design' );
function shark_news_entertainment_add_slider_widget_design() {
    return 'layout-2';
}